GlyphData

Struct GlyphData 

pub struct GlyphData<'a> {
    data: FontData<'a>,
}
Glyph data table

Fields

data: FontData<'a>

Implementations

Source

impl<'a> GlyphData<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn origin_offset_x(&self) -> i16

The horizontal (x-axis) position of the left edge of the bitmap graphic in relation to the glyph design space origin.

pub fn origin_offset_y(&self) -> i16

The vertical (y-axis) position of the bottom edge of the bitmap graphic in relation to the glyph design space origin.

pub fn graphic_type(&self) -> Tag

Indicates the format of the embedded graphic data: one of ’jpg ’, ’png ’ or ‘tiff’, or the special format ‘dupe’.

pub fn data(&self) -> &'a [u8]

The actual embedded graphic data. The total length is inferred from sequential entries in the glyphDataOffsets array and the fixed size (8 bytes) of the preceding fields.

pub fn origin_offset_x_byte_range(&self) -> Range<usize>

pub fn origin_offset_y_byte_range(&self) -> Range<usize>

pub fn graphic_type_byte_range(&self) -> Range<usize>

pub fn data_byte_range(&self) -> Range<usize>