Sbix

Struct Sbix 

pub struct Sbix<'a> {
    data: FontData<'a>,
    num_glyphs: u16,
}
Fields

data: FontData<'a>num_glyphs: u16

Implementations

Source

impl<'a> Sbix<'a>

pub fn read(data: FontData<'a>, num_glyphs: u16) -> Result<Self, ReadError>

A constructor that requires additional arguments.

This type requires some external state in order to be parsed.

Source

impl<'a> Sbix<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> u16

Table version number — set to 1.

pub fn flags(&self) -> HeaderFlags

Bit 0: Set to 1. Bit 1: Draw outlines. Bits 2 to 15: reserved (set to 0).

pub fn num_strikes(&self) -> u32

Number of bitmap strikes.

pub fn strike_offsets(&self) -> &'a [BigEndian<Offset32>]

Offsets from the beginning of the ‘sbix’ table to data for each individual bitmap strike.

pub fn strikes(&self) -> ArrayOfOffsets<'a, Strike<'a>, Offset32>

A dynamically resolving wrapper for strike_offsets.

pub(crate) fn num_glyphs(&self) -> u16

pub fn version_byte_range(&self) -> Range<usize>

pub fn flags_byte_range(&self) -> Range<usize>

pub fn num_strikes_byte_range(&self) -> Range<usize>

pub fn strike_offsets_byte_range(&self) -> Range<usize>