Strike

Struct Strike 

pub struct Strike<'a> {
    data: FontData<'a>,
    num_glyphs: u16,
}
Strike header table

Fields

data: FontData<'a>num_glyphs: u16

Implementations

Source

impl<'a> Strike<'a>

pub fn read(data: FontData<'a>, num_glyphs: u16) -> Result<Self, ReadError>

A constructor that requires additional arguments.

This type requires some external state in order to be parsed.

Source

impl<'a> Strike<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn ppem(&self) -> u16

The PPEM size for which this strike was designed.

pub fn ppi(&self) -> u16

The device pixel density (in PPI) for which this strike was designed. (E.g., 96 PPI, 192 PPI.)

pub fn glyph_data_offsets(&self) -> &'a [BigEndian<u32>]

Offset from the beginning of the strike data header to bitmap data for an individual glyph ID.

pub(crate) fn num_glyphs(&self) -> u16

pub fn ppem_byte_range(&self) -> Range<usize>

pub fn ppi_byte_range(&self) -> Range<usize>

pub fn glyph_data_offsets_byte_range(&self) -> Range<usize>

Source

impl<'a> Strike<'a>

pub fn glyph_data( &self, glyph_id: GlyphId, ) -> Result<Option<GlyphData<'a>>, ReadError>