pub struct GlyphData<'a> {
data: FontData<'a>,
}Expand description
Glyph data table
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> GlyphData<'a>
impl<'a> GlyphData<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn origin_offset_x(&self) -> i16
pub fn origin_offset_x(&self) -> i16
The horizontal (x-axis) position of the left edge of the bitmap graphic in relation to the glyph design space origin.
Sourcepub fn origin_offset_y(&self) -> i16
pub fn origin_offset_y(&self) -> i16
The vertical (y-axis) position of the bottom edge of the bitmap graphic in relation to the glyph design space origin.
Sourcepub fn graphic_type(&self) -> Tag
pub fn graphic_type(&self) -> Tag
Indicates the format of the embedded graphic data: one of ’jpg ’, ’png ’ or ‘tiff’, or the special format ‘dupe’.
Sourcepub fn data(&self) -> &'a [u8] ⓘ
pub fn data(&self) -> &'a [u8] ⓘ
The actual embedded graphic data. The total length is inferred from sequential entries in the glyphDataOffsets array and the fixed size (8 bytes) of the preceding fields.