pub struct Strike<'a> {
data: FontData<'a>,
num_glyphs: u16,
}Expand description
Strike header table
Fields
data: FontData<'a>num_glyphs: u16Implementations
Sourceimpl<'a> Strike<'a>
impl<'a> Strike<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn ppi(&self) -> u16
pub fn ppi(&self) -> u16
The device pixel density (in PPI) for which this strike was designed. (E.g., 96 PPI, 192 PPI.)
Sourcepub fn glyph_data_offsets(&self) -> &'a [BigEndian<u32>]
pub fn glyph_data_offsets(&self) -> &'a [BigEndian<u32>]
Offset from the beginning of the strike data header to bitmap data for an individual glyph ID.
pub(crate) fn num_glyphs(&self) -> u16
pub fn ppem_byte_range(&self) -> Range<usize> ⓘ
pub fn ppi_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_data_offsets_byte_range(&self) -> Range<usize> ⓘ